/* This file is part of David Deaven's personal library.
 * Copyright (c) 1994 David Deaven
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Id: geodat.c,v 1.2 1995/10/10 14:49:18 deaven Exp $
 */

#include <stdio.h>
#include <string.h>
#include "dmd/geometry.h"
#include "dmd/memory.h"

char *usage = "usage: %s <options> [data file]\n"
  "options:\n"
  "\t-o ofn     Specify output file\n"
  "\t-s #       Scale coordinates (assumed bohr) by this\n"
  "\t-A         Use proper scale to read Angstroms\n"
  "\t-a aname   Specify atomic label\n"
  "\t-n         Read one cartesian per line\n"
  ;

int main(int argc, char **argv)
{
	int i, n, arg;
	int one_per_line = 0;
	double scale = 1.0;
	double x[3];
	Geometry *g;
	char *ifn = "-", *ofn = "-";
	char *aname = "X";
	FILE *fin, *fout;

	for(arg=1; arg<argc; ++arg)
	  if(argv[arg][0] == '-')
	    switch(argv[arg][1])
	    {
	      case 'o':
		ofn = argv[++arg];
		break;

	      case 's':
		sscanf(argv[++arg], "%lf", &scale);
		break;

	      case 'A':
		scale = (1.0 / 0.529177);
		break;
	      
	      case 'a':
		aname = argv[++arg];
		break;

	      case 'n':
		one_per_line = 1;
		break;

	      default:
	      	fprintf(stderr, usage, argv[0]);
	      	exit(1);
	    }
	  else
	    ifn = argv[arg];

	fin = (strcmp(ifn, "-") == 0 ? stdin : fopen(ifn, "r"));
	if(fin == NULL)
	{
		fprintf(stderr, "%s: cannot open %s\n", argv[0], ifn);
		exit(1);
	}

	fout = (strcmp(ofn, "-") == 0 ? stdout : fopen(ofn, "w"));
	if(fout == NULL)
	{
		fprintf(stderr, "%s: cannot open %s\n", argv[0], ofn);
		exit(1);
	}

	n = 0;
	g = NULL;
	while(fscanf(fin, "%lf %lf %lf", x, x + 1, x + 2) == 3) {
	  g = Grealloc(g, n + 1);
	  for(i=0; i<3; ++i) g->x[3*n + i] = scale * x[i];
	  g->aname[n] = aname;
	  ++n;
	  if(one_per_line) while(!feof(fin) && fgetc(fin) != '\n');
	}

	if(n > 0) {
	  g->name = "Created by geodat\n";
	  Gprint(fout, g);
	}
	else
	  fprintf(stderr, "Read no coordinates!\n");

	if(fin != stdin) fclose(fin);
	if(fout != stdout) fclose(fout);

	return 0;
}
