/* This file is part of David Deaven's personal library.
 * Copyright (c) 1994 David Deaven
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Id: geodiff.c,v 1.3 1995/11/22 16:42:07 deaven Exp $
 */

#include <stdio.h>
#include "dmd/geometry.h"

static char *usage =
  "usage: %s [-o fn] [-n ngrid] [-r res] geometry geometry\n";

void main(int argc, char **argv)
{
	Geometry *g1 = NULL, *g2 = NULL;
	int arg;
	double rms;
	int ngrid = 8;
	double res = 0.05;
	char *fn, *ofn = NULL;
	FILE *f = NULL;

	for(arg=1; arg<argc; ++arg)
	{
	  if(argv[arg][0] == '-')
	  {
	    switch(argv[arg][1])
	    {
	      case 'o': 
		ofn = argv[++arg];
		break;
	      case 'n':
		sscanf(argv[++arg], "%d", &ngrid);
		break;
	      case 'r':
		sscanf(argv[++arg], "%lf", &res);
		break;
	      default:
		fprintf(stderr, usage, argv[0]);
		exit(1);
	    }
	  }
	  else /* geometry filename */
	  {
	    f = fopen(fn = argv[arg], "r");
	    if(f == NULL) {
	      fprintf(stderr, "%s: cannot open %s\n", argv[0], fn);
	      exit(1);
	    }
	    if(g1 == NULL) g1 = Gread(f);
	    else g2 = Gread(f);
	  }
	}

	if (g2 == NULL)  /* no geometry -- try to read stdin */
	  g2 = Gread(stdin);

	if(g2 == NULL)
	{
	  fprintf(stderr, "%s: need geometry\n", argv[0]);
	  exit(1);
	}

	printf("comparing %s and %s\n", g1->name, g2->name);
	rms = Gdiff_spec(g1, g2, ngrid, res);
	printf("RMS difference = %g (ngrid=%d res=%g)\n", rms, ngrid, res);

	if(ofn != NULL)
	{
	  if((f = fopen(ofn, "w")) == NULL) {
		  fprintf(stderr, "%s: cannot open %s\n", argv[0], ofn);
		  exit(1);
	  }
	  Gprint(f, g1);
	  Gprint(f, g2);
	  fclose(f);
	}

	exit(0);
}
