/* This file is part of David Deaven's personal library.
 * Copyright (c) 1994 David Deaven
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Id: geolattice.c,v 1.2 1995/10/10 14:49:18 deaven Exp $
 */

#include <stdio.h>
#include <string.h>
#include "dmd/geometry.h"
#include "dmd/memory.h"

char *usage = "usage: %s [-v] [-x n] [-y n] [-z n] [-o output_file] geometry\n";

/* Make a lattice
 */
void main(int argc, char **argv)
{
  Geometry *g = NULL, *lg;
  int arg, nx=2, ny=2, nz=2;
  int verbose = 0;
  char *fn = NULL, *ofn = "-";
  FILE *f = NULL;

  for(arg=1; arg<argc; ++arg) {
    if(argv[arg][0] == '-') {
      switch(argv[arg][1]) {
	case 'v':
	  verbose = 1;
	  break;
	case 'x':
	  sscanf(argv[++arg], "%d", &nx);
	  break;
	case 'y':
	  sscanf(argv[++arg], "%d", &ny);
	  break;
	case 'z':
	  sscanf(argv[++arg], "%d", &nz);
	  break;
	case 'o':
	  ofn = argv[++arg];
	  break;
	default:
	  fprintf(stderr, usage, argv[0]);
	  exit(1);
      }
    } else { /* geometry filename */
      fn = argv[arg];
      f = (strcmp(fn, "-") ? fopen(fn, "r") : stdin);
      if(f == NULL) {
	fprintf(stderr, "%s: cannot open %s\n", argv[0], fn);
	exit(1);
      }
      if((g = Gread(f)) == NULL) {
	fprintf(stderr, "%s: cannot read %s\n", argv[0], fn);
	exit(1);
      }
      if(f != stdin) fclose(f);
    }
  }

  if (g == NULL) { /* no geometry -- try to read stdin */
    g = Gread(stdin);
  }
  if(g == NULL) {
    fprintf(stderr, "%s: need geometry\n", argv[0]);
    exit(1);
  }

  if(verbose) {
    printf("unit cell volume = %.10g bohr^3\n", Gvolume(g));
  }

  lg = Glattice(g, 1, nx, 1, ny, 1, nz);

  if((f = strcmp(ofn, "-") == 0 ? stdout : fopen(ofn, "w")) == NULL) {
  	fprintf(stderr, "%s: cannot open `%s'\n", argv[0], ofn);
  	exit(1);
  }
  Gprint(f, lg);
  if(f != stdout) fclose(f);

  Gfree(g);
  Gfree(lg);
  exit(0);
}
